@@ -1,19 +1,19 @@
 man.evenn <-
 function()
 {
-  write("        ,.-.,                                                                                      ", file="")
-  write("      .`     `.                                                                                    ", file="")
-  write("     /.-., ,.-.`            *       *                                   ****      **           *   ", file="")
-  write("   .`    .`.    `.     ***   *     *   ***    ****   ****              *    *   *  *         * *   ", file="")
-  write("  / `.  /   `.  / `  *     *  *   *  *     * *    * *    *      *   *      *       *        *  *   ", file="")
-  write(" |    ',_____,'    | ******   *   *  ******  *    * *    *      *   *     *        *       *   *   ", file="")
-  write(" `.     `   /     /  *         * *   *       *    * *    *       * *    *          *      *******  ", file="")
-  write("   ',    '_'    ,'    *****     *     *****  *    * *    *        *    ****** * ******* *      *   ", file="")
-  write("     `'-'` `'-'`                                                                                   ", file="")
+  write("        ,.-.,                                                                                    ", file="")
+  write("      .`     `.                                                                                  ", file="")
+  write("     /.-., ,.-.`            *       *                                 ****      **      *******  ", file="")
+  write("   .`    .`.    `.     ***   *     *   ***    ****   ****    *     * *    *   *  *      *        ", file="")
+  write("  / `.  /   `.  / `  *     *  *   *  *     * *    * *    *    *   *      *       *      ******   ", file="")
+  write(" |    ',_____,'    | ******   *   *  ******  *    * *    *     * *      *        *            *  ", file="")
+  write(" `.     `   /     /  *         * *   *       *    * *    *     * *    *          *            *  ", file="")
+  write("   ',    '_'    ,'    *****     *     *****  *    * *    *      *    ****** * ******* * ******   ", file="")
+  write("     `'-'` `'-'`                                                                                 ", file="")
   write("\n#####################", file="")
   write("# eVenn Quick Start #", file="")
   write("#####################", file="")
-  write("- Prototype:\n\t(annot=FALSE, path_res=\"\", path_lists=\"\", res=\"\", ud=FALSE, prop=FALSE, noms=\"\", overlaps=FALSE, f=0, aa=FALSE)", file="")
+  write("- Prototype:\n\t(annot=FALSE, path_res=\"\", path_lists=\"\", res=\"\", ud=FALSE, prop=FALSE, noms=\"\", overlaps=FALSE, f=0, display=FALSE)", file="")
   write("- Text tabulated files must be placed alone in a folder.", file="")
   write("- Linux users must use the put the folder path in \"path_lists\".", file="")
   write("- Default option produce a classical Venn diagram:\n\tevenn()", file="")
@@ -37,6 +37,6 @@ function()
   write("\t\t\tA heatmap is created if at least three lists are processed.", file="")
   write("- f [0:1]:\tProduces a filtered matrix with overlaps proportions greater than f. Default f=0 is set to no filter..", file="")
   write("- Tk [TRUE/FALSE]:\tUse the tcltk library to graphically choose the source folder (Source lists), only with Linux.", file="")
-  write("- aa [TRUE/FALSE]:\tDraw a title in ascii art.", file="")
+  write("- display [TRUE/FALSE]:\tDraw a title in ascii art.", file="")
 }
 
